use crate::components::websocket::WebSocketContext;
use leptos::prelude::*;
use leptos_use::core::ConnectionReadyState;
use lib::*;
use thaw::*;

#[component]
pub fn Debug() -> impl IntoView {
    let websocket = expect_context::<WebSocketContext>();
    let server_online_users = expect_context::<ReadSignal<Option<ServerOnlineUsers>>>();
    let server_active_games = expect_context::<ReadSignal<Option<ServerActiveGames>>>();

    // Signals
    let user_count = RwSignal::new(0);
    let game_count = RwSignal::new(0);

    // Websocket stuff
    let status = move || websocket.ready_state.get().to_string();
    let connected = RwSignal::new(false);
    let disconnected = RwSignal::new(false);
    Effect::new(move |_| {
        connected.set(websocket.ready_state.get() == ConnectionReadyState::Open);
        disconnected.set(websocket.ready_state.get() == ConnectionReadyState::Closed)
    });
    let open_connection = move |_| {
        (websocket.open)();
    };

    let close_connection = move |_| {
        (websocket.close)();
        user_count.set(0);
        game_count.set(0);
    };

    // Update data on incoming updates
    Effect::new(move |_| {
        server_online_users.with(move |server_online_users| {
            if let Some(online_users) = server_online_users {
                user_count.set(online_users.online_users);
            };
        })
    });

    Effect::new(move |_| {
        server_active_games.with(move |server_active_games| {
            if let Some(active_games) = server_active_games {
                game_count.set(active_games.active_games);
            };
        })
    });

    view! {
        <div class="my-2 w-auto">
            <h2 class="p-1 text-2xl">Debug:</h2>
            <p class="p-1">"Connection Status: " {status}</p>
            <p class="p-1">"Users Online: " {user_count}</p>
            <p class="p-1">"Active Games: " {game_count}</p>
            <div class="p-1">
                <Button on_click=open_connection disabled=connected>
                    "Connect"
                </Button>
                <Button on_click=close_connection disabled=disconnected>
                    "Disconnect"
                </Button>
            </div>
        </div>
    }
}
