use leptos::prelude::*;
use lib::*;

#[component]
fn Meta() -> impl IntoView {
    let game_meta = expect_context::<ReadSignal<Option<GameMeta>>>();

    view! {
        <div class="shrink-0">
            <p>{move || game_meta().unwrap().name}</p>
            <p>"⬜ " {move || game_meta().unwrap().white_count}</p>
            <p>"⬛ " {move || game_meta().unwrap().black_count}</p>
            <p>"♻  " {move || game_meta().unwrap().white_discard_count}</p>
        </div>
    }
}

#[component]
fn Scoreboard() -> impl IntoView {
    let game_meta = expect_context::<ReadSignal<Option<GameMeta>>>();

    view! {
        <Show when=move || { game_meta().is_some() }>
            <table class="table-auto">
                <thead>
                    <tr>
                        <th></th>
                        <th></th>
                        <th>"Score"</th>
                    </tr>
                </thead>
                {game_meta()
                    .unwrap()
                    .players
                    .into_iter()
                    .map(|player| {
                        view! {
                            <tr>
                                <td>
                                    {if game_meta().unwrap().czar == player.name {
                                        "👑"
                                    } else if player.submitted {
                                        "🟢"
                                    } else {
                                        "⚫"
                                    }}
                                </td>
                                <td>
                                    {if game_meta().unwrap().host == player.name {
                                        "⚜  "
                                    } else {
                                        ""
                                    }} {player.name}
                                </td>
                                <td class="text-center">{player.score}</td>
                            </tr>
                        }
                    })
                    .collect_view()}
            </table>
        </Show>
    }
}

#[component]
pub fn Header() -> impl IntoView {
    view! {
        <div class="flex flex-wrap justify-between">
            <Meta />
            <Scoreboard />
        </div>
    }
}
